@@ -10,19 +10,23 @@ import random
 
 sys.path.append(".")
 
-from itb_text_name import \
-    and_list, \
-    capitalize_name, \
-    get_gender, \
-    leet, \
-    normalize_name, \
-    sort_names, \
+from itb_text_name import (
+    and_list,
+    capitalize_name,
+    get_gender,
+    leet,
+    map_special_chars,
+    normalize_name,
+    sort_names,
     could_be_a_name
+)
 
 reference_names = {
     'Georg Pfolz': {
         'lowercase': 'georg pfolz',
         'capitalized': 'Georg Pfolz',
+        'ascii': 'Georg Pfolz',
+        'sort': 'Georg Pfolz',
         'gender': 'male',
         'is_a_name': True,
         'human_name': {
@@ -37,6 +41,8 @@ reference_names = {
     'Patrizia Höfstädter': {
         'lowercase': 'patrizia höfstädter',
         'capitalized': 'Patrizia Höfstädter',
+        'ascii': 'Patrizia Hoefstaedter',
+        'sort': 'Patrizia Hofstadter',
         'gender': 'female',
         'is_a_name': True,
         'human_name': {
@@ -51,6 +57,8 @@ reference_names = {
     'Eugénie Caraçon': {
         'lowercase': 'eugénie caraçon',
         'capitalized': 'Eugénie Caraçon',
+        'ascii': 'Eugenie Caracon',
+        'sort': 'Eugenie Caracon',
         'gender': 'female',
         'is_a_name': True,
         'human_name': {
@@ -65,6 +73,8 @@ reference_names = {
     'Joanna MacArthur': {
         'lowercase': 'joanna macarthur',
         'capitalized': 'Joanna MacArthur',
+        'ascii': 'Joanna MacArthur',
+        'sort': 'Joanna MacArthur',
         'gender': 'female',
         'is_a_name': True,
         'human_name': {
@@ -79,6 +89,8 @@ reference_names = {
     'Sandra de Vitt': {
         'lowercase': 'sandra de vitt',
         'capitalized': 'Sandra de Vitt',
+        'ascii': 'Sandra de Vitt',
+        'sort': 'Sandra de Vitt',
         'gender': 'female',
         'is_a_name': True,
         'human_name': {
@@ -93,6 +105,8 @@ reference_names = {
     'Bea-Regina Obersteigen': {
         'lowercase': 'bea-regina obersteigen',
         'capitalized': 'Bea-Regina Obersteigen',
+        'ascii': 'Bea-Regina Obersteigen',
+        'sort': 'Bea-Regina Obersteigen',
         'gender': 'female',
         'is_a_name': True,
         'human_name': {
@@ -104,14 +118,16 @@ reference_names = {
             'nickname': ''
         }
     },
-    'Roland Meier-Lansky': {
-        'lowercase': 'roland meier-lansky',
-        'capitalized': 'Roland Meier-Lansky',
+    'Antun Meier-Lansky': {
+        'lowercase': 'antun meier-lansky',
+        'capitalized': 'Antun Meier-Lansky',
+        'ascii': 'Antun Meier-Lansky',
+        'sort': 'Antun Meier-Lansky',
         'gender': 'male',
         'is_a_name': True,
         'human_name': {
             'title': '',
-            'first': 'Roland',
+            'first': 'Antun',
             'middle': '',
             'last': 'Meier-Lansky',
             'suffix': '',
@@ -121,6 +137,8 @@ reference_names = {
     'Bogumila Österreicher': {
         'lowercase': 'bogumila österreicher',
         'capitalized': 'Bogumila Österreicher',
+        'ascii': 'Bogumila Oesterreicher',
+        'sort': 'Bogumila Osterreicher',
         'gender': 'unknown',
         'is_a_name': True,
         'human_name': {
@@ -135,6 +153,8 @@ reference_names = {
     'Rafael': {
         'lowercase': 'rafael',
         'capitalized': 'Rafael',
+        'ascii': 'Rafael',
+        'sort': 'Rafael',
         'gender': 'male',
         'is_a_name': True,
         'human_name': {
@@ -149,6 +169,8 @@ reference_names = {
     'Maria Helena Blawatsky': {
         'lowercase': 'maria helena blawatsky',
         'capitalized': 'Maria Helena Blawatsky',
+        'ascii': 'Maria Helena Blawatsky',
+        'sort': 'Maria Helena Blawatsky',
         'gender': 'female',
         'is_a_name': True,
         'human_name': {
@@ -163,6 +185,8 @@ reference_names = {
     'DsZHkfNijWFPrET JGLAjuaqZ': {
         'lowercase': 'dszhkfnijwfpret jglajuaqz',
         'capitalized': 'Dszhkfnijwfpret Jglajuaqz',
+        'ascii': 'DsZHkfNijWFPrET JGLAjuaqZ',
+        'sort': 'DsZHkfNijWFPrET JGLAjuaqZ',
         'gender': 'unknown',
         'is_a_name': False,
         'human_name': {
@@ -173,20 +197,54 @@ reference_names = {
             'suffix': '',
             'nickname': ''
         }
+    },
+    'Bethy De La Cruz': {
+        'lowercase': 'bethy de la cruz',
+        'capitalized': 'Bethy de la Cruz',
+        'ascii': 'Bethy De La Cruz',
+        'sort': 'Bethy De La Cruz',
+        'gender': 'unknown',
+        'is_a_name': True,
+        'human_name': {
+            'title': '',
+            'first': 'Bethy',
+            'middle': '',
+            'last': 'De La Cruz',
+            'suffix': '',
+            'nickname': ''
+        }
+    },
+    'Robert Štetić': {
+        'lowercase': 'robert štetić',
+        'capitalized': 'Robert Štetić',
+        'ascii': 'Robert Stetic',
+        'sort': 'Robert Stetic',
+        'gender': 'male',
+        'is_a_name': True,
+        'human_name': {
+            'title': '',
+            'first': 'Robert',
+            'middle': '',
+            'last': 'Štetić',
+            'suffix': '',
+            'nickname': ''
+        }
     }
 }
 
 reference_names_sorted = [
     'Maria Helena Blawatsky',
     'Eugénie Caraçon',
+    'Bethy De La Cruz',
     'Patrizia Höfstädter',
     'DsZHkfNijWFPrET JGLAjuaqZ',
     'Joanna MacArthur',
-    'Roland Meier-Lansky',
+    'Antun Meier-Lansky',
     'Bea-Regina Obersteigen',
     'Bogumila Österreicher',
     'Georg Pfolz',
     'Rafael',
+    'Robert Štetić',
     'Sandra de Vitt'
 ]
 
@@ -247,6 +305,34 @@ class TestTextName(unittest.TestCase):
                 msg = f'{gender} != {correct_gender} for {name}'
                 raise AssertionError(msg)
 
+    def test_map_special_chars(self):
+        for name, name_dict in reference_names.items():
+            correct_ascii = name_dict.get('ascii')
+            ascii_str = map_special_chars(text=name)
+
+            try:
+                self.assertEqual(
+                    ascii_str,
+                    correct_ascii
+                )
+            except AssertionError:
+                msg = f'ASCII: {ascii_str} != {correct_ascii} for {name}'
+                raise AssertionError(msg)
+
+    def test_map_special_chars_sort(self):
+        for name, name_dict in reference_names.items():
+            correct_sort = name_dict.get('sort')
+            sort_str = map_special_chars(text=name, sort=True)
+
+            try:
+                self.assertEqual(
+                    sort_str,
+                    correct_sort
+                )
+            except AssertionError:
+                msg = f'SORT: {sort_str} != {correct_sort} for {name}'
+                raise AssertionError(msg)
+
     def test_normalize_name(self):
         for name, name_dict in reference_names.items():
             normalized_name = normalize_name(
@@ -282,10 +368,14 @@ class TestTextName(unittest.TestCase):
             if not ' ' in name:
                 kwargs['prename'] = True
 
-            self.assertEqual(
-                could_be_a_name(**kwargs),
-                vals.get('is_a_name')
-            )
+            try:
+                self.assertEqual(
+                    could_be_a_name(**kwargs),
+                    vals.get('is_a_name')
+                )
+            except AssertionError as e:
+                msg = f'could_be_a_name failed on {name}'
+                raise AssertionError(msg)
 
 
 if __name__ == '__main__':
